@@ -4,6 +4,13 @@
 #include <termios.h>
 #include <sys/ioctl.h>
 
+/* this ifdef fixes read_pass on freebsd */
+#ifdef TIOCSETA
+#define termio termios
+#define TCSETA TIOCSETA
+#define TCGETA TIOCGETA
+#endif
+
 /*
  * read the password in from the user, returns NULL on an error, based upon
  * sample code in the excellent book "Building Secure Software" by John Viega
